"""Unit Tests for the module"""

import logging
import os

from django.core.files import File as DjangoFile
from django.test import TestCase
from django.urls import reverse
from filer.models.imagemodels import Image

from tests.helpers import create_image, create_superuser

LOGGER = logging.getLogger(name="django-filer-optimizer")


class TestCase(TestCase):
    """Test Case for django-filer-optimizer"""

    def setUp(self):
        """Set up common assets for tests"""
        LOGGER.debug("Tests setUp")
        self.superuser = create_superuser()
        self.client.login(username="admin", password="secret")
        self.img = create_image()
        self.image_name = "test_file.jpg"
        self.filename = os.path.join(os.path.dirname(__file__), self.image_name)
        self.img.save(self.filename, "JPEG")
        with open(self.filename, "rb") as upload:
            self.file_object = Image.objects.create(
                file=DjangoFile(upload, name=self.image_name)
            )
        super().setUp()

    def tearDown(self):
        """Remove Test Data"""
        LOGGER.debug("Tests tearDown")
        self.client.logout()
        os.remove(self.filename)
        for img in Image.objects.all():
            img.delete()
        super().tearDown()

    # @patch('filer_optimizer.signals.image_optimizer.send')
    def test_upload_image_form(self, extra_headers={}):
        # self.assertEqual(Image.objects.count(), 0)
        with open(self.filename, "rb") as fh:
            file_obj = DjangoFile(fh)
            url = reverse("admin:filer-ajax_upload")
            post_data = {
                "Filename": self.image_name,
                "Filedata": file_obj,
                "jsessionid": self.client.session.session_key,
            }
            response = self.client.post(url, post_data, **extra_headers)  # noqa
            # self.assertEqual(Image.objects.count(), 1)
            stored_image = Image.objects.first()
            # self.assertEqual(stored_image.original_filename, self.image_name)
            self.assertEqual(stored_image.mime_type, "image/jpeg")

        # # Check that your signal was called.
        # self.assertTrue(mock.called)
        #
        # # Check that your signal was called only once.
        # self.assertEqual(mock.call_count, 1)



#!/usr/bin/python

# -*- coding: utf-8 -*-
from django.core.management.base import BaseCommand, CommandError
from filer.models.imagemodels import Image

from filer_optimizer.utils import generate_thumbnails


class Command(BaseCommand):
    help = "List all images in Filer module"

    def handle(self, *args, **options):
        try:
            for image in Image.objects.all():
                self.stdout.write(f"----------------------")
                self.stdout.write(
                    f"{image} - {image.width}x{image.height} - {image.mime_type} - {image.file}"
                )
                try:
                    generate_thumbnails(image)
                except Exception as err:
                    self.stdout.write(f"[+] ERROR-THUMBS: {err}!!!")
        except Exception as err:
            self.stdout.write(f"[+] ERROR: {err}!!!")
            raise CommandError(f"Program INFO:[{err}]")



from django.conf import settings

from .utils import setting

settings.THUMBNAIL_PREFIX = setting("THUMBNAIL_PREFIX", "thumbs_")

settings.THUMBNAIL_NAMER = setting(
    "THUMBNAIL_NAMER", "easy_thumbnails.namers.source_hashed"
)

settings.THUMBNAIL_HIGH_RESOLUTION = setting("THUMBNAIL_HIGH_RESOLUTION", True)

settings.THUMBNAIL_PROCESSORS = setting(
    "THUMBNAIL_PROCESSORS",
    (
        "easy_thumbnails.processors.colorspace",
        "easy_thumbnails.processors.autocrop",
        # 'easy_thumbnails.processors.scale_and_crop',
        "filer.thumbnail_processors.scale_and_crop_with_subject_location",
        "easy_thumbnails.processors.filters",
    ),
)

settings.THUMBNAIL_ALIASES = setting(
    "THUMBNAIL_ALIASES",
    {
        "default": {
            "head": {"size": (1920, 1080), "crop": True},
            "middle": {"size": (1080, 1620), "crop": True},
            "preview": {"size": (750, 480), "crop": True},
            "grid": {"size": (800, 720), "crop": True},
            "70": {"size": (70, 70), "crop": True},
            "130": {"size": (130, 130), "crop": True},
            "250": {"size": (250, 250), "crop": True},
        },
    },
)

settings.FILER_WEBP_QUALITY = setting("FILER_WEBP_QUALITY", 80)
settings.FILER_AVIF_QUALITY = setting("FILER_AVIF_QUALITY", 60)

# todo: this overwrite is not take in account by filer
settings.FILER_STORAGES = setting(
    "FILER_STORAGES",
    {
        "public": {
            "thumbnails": {
                "THUMBNAIL_OPTIONS": {"base_dir": ""},
            },
        },
    },
)



from django.contrib.auth.models import User
from PIL import Image, ImageDraw


def create_superuser():
    superuser = User.objects.create_superuser("admin", "admin@django.it", "secret")
    return superuser


def create_image(mode="RGB", size=(800, 600)):
    image = Image.new(mode, size)
    draw = ImageDraw.Draw(image)
    x_bit, y_bit = size[0] // 10, size[1] // 10
    draw.rectangle((x_bit, y_bit * 2, x_bit * 7, y_bit * 3), "red")
    draw.rectangle((x_bit * 2, y_bit, x_bit * 3, y_bit * 8), "red")
    return image
